import React, { useState, useEffect } from "react"
import Taro from "@tarojs/taro";
import { View, Input, Swiper, Image, SwiperItem, Text, ScrollView,Button } from "@tarojs/components"
import { Popup } from "@antmjs/vantui";
import positionImg from '@/assets/comm/position.png'
import searchImg from '@/assets/comm/search.png'
import orderImg from '@/assets/comm/orderList.png'
import PositionImg from '@/assets/job/positionImg.png'
import Footer from "@/components/Footer";
import MyCard from "@/components/MyCard";
import NullCard from "@/components/NullCard";
import { getBannerList } from "@/services/banner";
import { getJobList } from '@/services/job'
import './style.less'


export default (props) => {
  const [imgList, setImgList] = useState([])
  const [jobList, setJobList] = useState([])
  const [currentPage, setCurrentPage] = useState(1)
  const [isMore, setIsMore] = useState(false)
  const [q, setQ] = useState()
  
  const [show, setShow] = useState(false)
  const [area,setArea]=useState()
  const [showOver, setShowOver] = useState(false)

  const handleSearch = (e) => {
    setIsMore(false)
    setCurrentPage(1)
    setQ(e.detail.value)
  }
  const handleDetail = (val) => {
    Taro.navigateTo({ url: `/pages/orderDetail/index?id=${val}` });
  }
  // 上拉加载
  const handleScrollToLower = () => {
    setCurrentPage(currentPage + 1)
  }
  const handleChange = () => {
    setShow(true)
    // setShowOver(true)
  }
  const onClose = () => {
    setShow(false)
  }
  const handleOk = () => {
    console.log('开始作业')
    setShow(false)
  }
  const handleArea=(e)=>{
    setArea(e.detail.value)
  }
  const onOverClose=()=>{
    setArea()
    setShowOver(false)
  }
  const handleOverOk=()=>{
    if (area) {
      console.log(666)
    }
  }
  useEffect(() => {
    getJobList({ pageNum: currentPage, q: q }).then(res => {
      const lst = currentPage === 1 ? res.records || [] : jobList.concat(res.records || [])
      //长列表加载当下一页没有数据时
      if (res.records.length == 0 && currentPage != 1) {
        setIsMore(true)
        return
      }
      setJobList(lst)
    })
  }, [currentPage, q])
  useEffect(() => {
    getBannerList({ position: 'bannerWorker' })
      .then(res => {
        setImgList(res)
      }).catch(err => {
        Taro.showToast({
          title: '网络异常, 请刷新小程序重试',
          icon: 'none',
        })
      })
  }, [])
  return (
    <View className='orderIndex'>
      <View className='top'>
        <View className='left'>
          <Image src={positionImg} className='pImg' />
          <Text>邓州市</Text>
          <View className='icon' />
        </View>
        <View className='searchClass'>
          <Input type='text' className='searchInput' onBlur={handleSearch} placeholder='搜索关键字查询订单' />
          <Image src={searchImg} className='searchImg' />
        </View>
      </View>
      <ScrollView
        scrollY
        enhanced
        onScrollToLower={isMore ? '' : handleScrollToLower}
        style={{ height: 'calc(100% - 68px)' }}
      >
        <Swiper
          circular
          autoplay
          className='swiper'
        >
          {imgList.map((item, inx) => (
            <SwiperItem key={inx}>
              <Image src={item.thumb} mode='widthFix' className='storeImage' />
            </SwiperItem>
          ))}
        </Swiper>
        <View className='orderList'>
          <View className='head'>
            <Image className='headIcon' src={orderImg} />
            <Text className='title'>作业列表</Text>
          </View>
          {
            jobList.length === 0 ? <NullCard value='您还没有新的作业订单！' /> :
              jobList.map((item) => {
                return <MyCard job value={item} key={item.JobId} onClick={handleChange} goDetail={handleDetail} />
              })
          }
          {
            isMore && <Footer />
          }
        </View>
        <Popup
          show={show}
          onClose={onClose}
          className='tanchuang'
        >
          <Image src={PositionImg} className='pImg' />
          <View>当前位置在</View>
          <View>河南省南阳市邓州市孟楼镇</View>
          <Button className='btn' onClick={handleOk}>确认</Button>
        </Popup>
        <Popup
          show={showOver}
          onClose={onOverClose}
          className='tanchuang2'
        >
          <View className='bankInput'>
            <View className='header'>作业面积：</View>
            <Input className='body' type='digit' placeholder='请输入本次作业的面积' value={area} onBlur={handleArea} />
          </View>
          <Button className='btn' onClick={handleOverOk}>确认</Button>
        </Popup>

      </ScrollView>
    </View>
  )
}